import logging

import requests
from requests.structures import CaseInsensitiveDict
from requests import ReadTimeout, ConnectTimeout, HTTPError, Timeout, ConnectionError

import json

LOG = logging.getLogger(__name__)
HTTP_URL = "http://{0}:8000/rest/auth/external/homeassistant/"

class YIO(object):
    def __init__(self, host):
        self._host = host

    def sendToken(self, tokenId, name, token):

        headers = CaseInsensitiveDict()
        headers["Authorization"] = "Basic eWlvOnJlbW90ZQ=="
        headers["Content-Type"] = "application/json"

        data = {"id" : tokenId, "name" : name, "token" : token}

        url = HTTP_URL.format(self._host)

        try:
            r = requests.post(url, headers=headers, data=json.dumps(data))
            
            response = r.text
            LOG.debug("Response: %s", response)

            if (r.status_code == 200):
                return True
            
            if (r.status_code == 400):
                return False
            
            if (r.status_code == 404):
                return False

        except (ConnectTimeout, HTTPError, ReadTimeout, Timeout, ConnectionError):
            return False


import os
from setuptools import setup, find_packages

def readme():
    with open("README.md") as f:
        return f.read()

PACKAGE_NAME = "yiopypi"
HERE = os.path.abspath(os.path.dirname(__file__))
VERSION = "0.0.2"

PACKAGES = find_packages(exclude=["tests", "tests.*", "dist", "ccu", "build"])

REQUIRES = []

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    license="MIT License",
    url="https://github.com/YIO-Remote/yiopypi",
    author="Marton Borzak",
    author_email="marton@yio-remote.com",
    description="YIO Remote V2 API python library",
    long_description=readme(),
    long_description_content_type='text/markdown',
    packages=PACKAGES,
    include_package_data=True,
    zip_safe=False,
    platforms="any",
    install_requires=REQUIRES,
    keywords=["yio", "yioremote"],
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.4",
    ],
)
